@@ -1,7 +1,7 @@
 package Complete::TZ;
 
-our $DATE = '2015-09-17'; # DATE
-our $VERSION = '0.05'; # VERSION
+our $DATE = '2015-09-18'; # DATE
+our $VERSION = '0.06'; # VERSION
 
 use 5.010001;
 use strict;
@@ -34,7 +34,7 @@ on systems that have that.
 
 _
     args => {
-        word => { schema=>'str' },
+        word => { schema=>'str', pos=>0 },
     },
     result_naked => 1,
     result => {
@@ -77,7 +77,7 @@ Complete::TZ - Timezone-related completion routines
 
 =head1 VERSION
 
-This document describes version 0.05 of Complete::TZ (from Perl distribution Complete-TZ), released on 2015-09-17.
+This document describes version 0.06 of Complete::TZ (from Perl distribution Complete-TZ), released on 2015-09-18.
 
 =head1 DESCRIPTION
 
